--filter=-linelength,-readability/mixedcase CMakeLists.txt
1
126
CMakeLists.txt:13: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:50: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:238: Extra spaces between 'VISIBLE_IF' and its () [whitespace/extra]
CMakeLists.txt:276: Extra spaces between 'VISIBLE_IF' and its () [whitespace/extra]
CMakeLists.txt:393: Extra spaces between 'VISIBLE_IF' and its () [whitespace/extra]
CMakeLists.txt:433: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:434: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:435: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:437: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:441: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:442: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:443: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:445: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:451: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:452: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:453: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:454: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:463: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:464: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:466: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:473: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:474: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:475: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:476: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:477: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:484: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:485: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:554: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:864: Extra spaces between 'foreach' and its () [whitespace/extra]
CMakeLists.txt:871: Extra spaces between 'foreach' and its () [whitespace/extra]
CMakeLists.txt:1028: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1033: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1038: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1172: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1186: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1187: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1211: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1212: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1213: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1214: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1233: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1276: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1281: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:1285: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:1294: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1297: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1304: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1320: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:1320: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1321: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:1321: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1326: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1330: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1336: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1349: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1353: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1357: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1361: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1366: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1373: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1377: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1381: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1385: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1389: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1393: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1401: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1406: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1408: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1410: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1412: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1413: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1414: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1415: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1416: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1420: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1424: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1428: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1432: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1436: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1448: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1452: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1456: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1457: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1461: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1465: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1469: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1473: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1477: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1497: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1508: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1523: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1527: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1531: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1535: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1562: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1566: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1569: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1583: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1588: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1590: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1592: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1597: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1599: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1600: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1612: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1614: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1615: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1623: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1625: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1627: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1629: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1630: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1636: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1638: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1640: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1642: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1643: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1647: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1649: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1652: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1658: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1659: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1661: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1663: Expression repeated inside else; better to use only status() [readability/logic]
CMakeLists.txt:1664: Expression repeated inside else; better to use only status() [readability/logic]

Total Errors: 125

